import { Component, OnInit, Inject, AfterContentInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { Store, select } from '@ngrx/store';

import { RPCClientError } from '@loafer/ng-rpc/protocol';

import * as DetailStore from '../../store/detail';
import { DetailSelector } from '../../store';
import { Probe } from '../../model';
// import { SettingComponent as DiscoverySettingComponent } from 'packages/discovery/component/setting/setting.component';
import * as CIDR from 'ip-cidr';

@Component({
  selector: 'of-probe-detail',
  templateUrl: './detail.component.html',
  styleUrls: ['./detail.component.scss']
})
export class DetailComponent implements OnInit, AfterContentInit {

  probe$ = this.detailStore.pipe(select(DetailSelector.select('probe')));
  probe: Probe = null;
  networkInfo = null;
  deviceInfo = null;
  probeInfo = null;


  constructor(
    private route: ActivatedRoute,
    private router: Router,
    // public dialog: MatDialog,
    private detailStore: Store<DetailStore.State>
  ) { }

  ngOnInit() {
    this.probe$.subscribe(
      (probe: Probe) => {
        if (probe != null) {
          this.probe = probe;
          console.log(probe);
          this.arrangeInfo();
        }
      },
      (error: RPCClientError) => {
        console.log(error.response.message);
      }
    );
  }

  ngAfterContentInit() {
    const probeId = this.route.snapshot.paramMap.get('id');
    this.detailStore.dispatch(
      new DetailStore.Read(
        { id: probeId }
      )
    );
  }

  arrangeInfo() {

    const cidr = new CIDR(this.probe.cidr);
    if (!cidr.isValid()) {
    }
    const startIP = cidr.addressStart.address;
    const endIP = cidr.addressEnd.address;

    this.networkInfo = [
      {
        key: 'Probe IP Range',
        value: startIP + '~' + endIP,
      },
      {
        key: 'Installed IP',
        value: '???',
      },
      {
        key: 'NIC',
        value: '???'
      },
      {
        key: 'Targets',
        value: 'count 반정규화 필요 '
      },
    ];
    this.deviceInfo = [
      {
        key: 'OS',
        value: 'Linux'
      },
      {
        key: 'CPU',
        value: 'intel7...'
      },
      {
        key: 'Memory',
        value: '16GB'
      },
      {
        key: '...',
        value: '...'
      },
    ];
    this.probeInfo = [
      {
        key: 'Authorized at',
        value: String(new Date(this.probe.authorizeDate))
      },
      {
        key: 'Authorized by',
        value: 'insanity'
      },
      {
        key: 'Installed at',
        value: String(new Date(this.probe.createDate))
      },
      {
        key: 'Probe Key',
        value: this.probe.probeKey,
      },
    ];
  }

  discovery() {
    // const dialogRef = this.dialog.open(DiscoverySettingComponent, {
    //   width: '80%',
    // });

    // dialogRef.afterClosed().subscribe(result => {
    //   console.log('The dialog was closed');

    // });
  }


  handleStartStop() {
    // this.isUpState = !this.isUpState;
  }

  handleRemove() {
    // const dialogRef = this.dialog.open(ConfirmDialogComponent, {
    //   width: '250px',
    //   data: {
    //     title: 'Remove',
    //     message: 'Are you sure?'
    //   }
    // });

    // dialogRef.afterClosed().subscribe(confirmed => {
    //   if (confirmed) {
    //     console.log('confirmed');
    //   }
    //   // 삭제 후 list로 back
    // });
  }
}

