import { Component, OnInit, AfterViewInit, AfterContentInit, ViewChild } from '@angular/core';
import { Router } from '@angular/router';

import { Store, select } from '@ngrx/store';

import { RPCClientError } from '@loafer/ng-rpc/protocol';
import { Domain } from 'packages/domain/model';
import { AuthSelector } from 'packages/member/store';

import { Probe } from '../../model';
import * as ListStore from '../../store/list';
import { ListSelector } from '../../store';

@Component({
  selector: 'of-probe-list',
  templateUrl: './list.component.html',
  styleUrls: ['./list.component.scss']
})
export class ListComponent implements OnInit, AfterContentInit {
  probes$ = this.store.pipe(select(ListSelector.select('probes')));
  probes: Probe[];
  cols: any[];

  constructor(
    private router: Router,
    private store: Store<ListStore.State>
  ) {
  }

  ngAfterContentInit() {

    this.store.select(AuthSelector.select('domain')).subscribe(
      (domain: Domain) => {
        this.store.dispatch(new ListStore.ReadAllByDomain(domain));
      },
      (error) => {
        console.log(error);
      }
    );

    this.probes$.subscribe(
      (probes: Probe[]) => {
        console.log(probes);
      },
      (error: RPCClientError) => {
        console.log(error.response.message);
      }
    );

  }

  ngOnInit() {
    this.cols = [
      { field: 'displayName', header: 'displayName' },
      { field: 'createDate', header: 'createDate' },
      { field: 'cidr', header: 'CIDR' },
      { field: 'authorizeDate', header: 'authorizeDate' },
      { field: 'authorizeMember', authorizeMember: 'Color' }
    ];

    // Temporary data
    this.probes = new Array();
    for (let i = 0; i < 10; i++) {
      const p: Probe = {
        id: i,
        createDate: new Date(),
        description: 'Description' + i,
        displayName: 'DisplayName' + i,
        cidr: 'CIDR' + i,
        authorizeDate: new Date(),
        authorizeMember: {
          name: 'MemberName' + i,
        },
      };
      this.probes.push(p);
    }
  }

  onRowSelect(event) {
    console.log(event.data);
    // this.router.navigate(['probe', obj.id]);
  }
}
